==> seedsui-react-5.5.91.tgz: package/lib/DateRangePopover/DateRange.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useState, useEffect } from 'react';
import Alert from "./../Alert";
import InputDate from "./../InputDate";
import locale from "./../locale"; // 自定义时间

import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

function DateRange(_ref) {
  var caption = _ref.caption,
      type = _ref.type,
      start = _ref.start,
      end = _ref.end,
      _ref$startInputDatePr = _ref.startInputDateProps,
      startInputDateProps = _ref$startInputDatePr === void 0 ? {} : _ref$startInputDatePr,
      _ref$endInputDateProp = _ref.endInputDateProps,
      endInputDateProps = _ref$endInputDateProp === void 0 ? {} : _ref$endInputDateProp,
      visible = _ref.visible,
      onVisibleChange = _ref.onVisibleChange,
      onSubmitBefore = _ref.onSubmitBefore,
      onChange = _ref.onChange;

  // 自定义日期数据
  var _useState = useState(start),
      _useState2 = _slicedToArray(_useState, 2),
      customStart = _useState2[0],
      setCustomStart = _useState2[1];

  var _useState3 = useState(end),
      _useState4 = _slicedToArray(_useState3, 2),
      customEnd = _useState4[0],
      setCustomEnd = _useState4[1];

  useEffect(function () {
    setCustomStart(start);
    setCustomEnd(end);
  }, [start, end]); // 点击自定义取消

  function handleCustomCancel() {
    if (onVisibleChange) onVisibleChange(false);
    setCustomStart(start);
    setCustomEnd(end);
  } // 点击自定义确定


  function handleCustomSubmit(e) {
    if (typeof onSubmitBefore === 'function') {
      if (!onSubmitBefore(e, [customStart, customEnd])) {
        return;
      }
    }

    if (onChange) {
      onChange(e, [customStart, customEnd]);
    }

    if (onVisibleChange) onVisibleChange(false);
  } // 修改自定义开始时间


  function handleCustomStartDate(e, value) {
    setCustomStart(value);
  } // 修改自定义结束时间


  function handleCustomEndDate(e, value) {
    setCustomEnd(value);
  }

  return /*#__PURE__*/_jsxs(Alert, {
    caption: caption || '',
    show: visible,
    submitAttribute: {
      onClick: handleCustomSubmit
    },
    cancelAttribute: {
      onClick: handleCustomCancel
    },
    children: [/*#__PURE__*/_jsx(InputDate, _objectSpread({
      type: type || 'date',
      max: customEnd,
      value: customStart || start || '',
      onChange: handleCustomStartDate,
      placeholder: locale('请选择'),
      className: "datepopover-dialog-inputbox",
      pickerProps: {
        maskAttribute: {
          style: {
            zIndex: '11'
          }
        }
      }
    }, startInputDateProps || {})), /*#__PURE__*/_jsx(InputDate, _objectSpread({
      type: type || 'date',
      min: customStart,
      value: customEnd || end || '',
      onChange: handleCustomEndDate,
      placeholder: locale('请选择'),
      className: "datepopover-dialog-inputbox",
      pickerProps: {
        maskAttribute: {
          style: {
            zIndex: '11'
          }
        }
      }
    }, endInputDateProps || {}))]
  });
}

export default DateRange;

==> seedsui-react-5.5.92.tgz: package/lib/DateRangePopover/DateRange.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useState, useEffect } from 'react';
import Alert from "./../Alert";
import InputDate from "./../InputDate";
import locale from "./../locale"; // 自定义时间

function DateRange(_ref) {
  var caption = _ref.caption,
      type = _ref.type,
      start = _ref.start,
      end = _ref.end,
      _ref$startInputDatePr = _ref.startInputDateProps,
      startInputDateProps = _ref$startInputDatePr === void 0 ? {} : _ref$startInputDatePr,
      _ref$endInputDateProp = _ref.endInputDateProps,
      endInputDateProps = _ref$endInputDateProp === void 0 ? {} : _ref$endInputDateProp,
      visible = _ref.visible,
      onVisibleChange = _ref.onVisibleChange,
      onSubmitBefore = _ref.onSubmitBefore,
      onChange = _ref.onChange;

  // 自定义日期数据
  var _useState = useState(start),
      _useState2 = _slicedToArray(_useState, 2),
      customStart = _useState2[0],
      setCustomStart = _useState2[1];

  var _useState3 = useState(end),
      _useState4 = _slicedToArray(_useState3, 2),
      customEnd = _useState4[0],
      setCustomEnd = _useState4[1];

  useEffect(function () {
    setCustomStart(start);
    setCustomEnd(end);
  }, [start, end]); // 点击自定义取消

  function handleCustomCancel() {
    if (onVisibleChange) onVisibleChange(false);
    setCustomStart(start);
    setCustomEnd(end);
  } // 点击自定义确定


  function handleCustomSubmit(e) {
    if (typeof onSubmitBefore === 'function') {
      if (!onSubmitBefore(e, [customStart, customEnd])) {
        return;
      }
    }

    if (onChange) {
      onChange(e, [customStart, customEnd]);
    }

    if (onVisibleChange) onVisibleChange(false);
  } // 修改自定义开始时间


  function handleCustomStartDate(e, value) {
    setCustomStart(value);
  } // 修改自定义结束时间


  function handleCustomEndDate(e, value) {
    setCustomEnd(value);
  }

  return /*#__PURE__*/React.createElement(Alert, {
    caption: caption || '',
    show: visible,
    submitAttribute: {
      onClick: handleCustomSubmit
    },
    cancelAttribute: {
      onClick: handleCustomCancel
    }
  }, /*#__PURE__*/React.createElement(InputDate, _extends({
    type: type || 'date',
    max: customEnd,
    value: customStart || start || '',
    onChange: handleCustomStartDate,
    placeholder: locale('请选择'),
    className: "datepopover-dialog-inputbox",
    pickerProps: {
      maskAttribute: {
        style: {
          zIndex: '11'
        }
      }
    }
  }, startInputDateProps || {})), /*#__PURE__*/React.createElement(InputDate, _extends({
    type: type || 'date',
    min: customStart,
    value: customEnd || end || '',
    onChange: handleCustomEndDate,
    placeholder: locale('请选择'),
    className: "datepopover-dialog-inputbox",
    pickerProps: {
      maskAttribute: {
        style: {
          zIndex: '11'
        }
      }
    }
  }, endInputDateProps || {})));
}

export default DateRange;
